package cz.cvut.fel.aos.caching.service;

import java.util.Date;
import java.util.Random;

import org.jboss.resteasy.util.DateUtil;

import cz.cvut.fel.aos.caching.model.Car;
import javax.ws.rs.GET;
import javax.ws.rs.HeaderParam;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

@Path("/cars")
public class CarService {

	private static String ETAG;
	private static Date MODIFIED;

	@GET
	@Path("/{carId:\\d+}/etag")
	@Produces(MediaType.APPLICATION_JSON)
	public Response getCarByEtag(@PathParam("carId") long carId, @HeaderParam("If-None-Match") String tag) {
		Random random = new Random();
		if (ETAG != null && ETAG.equals(tag) && random.nextBoolean()) {
			return Response.status(Response.Status.NOT_MODIFIED).header("ETag", tag).build();
		}
		ETAG = random.nextInt(50000) + "ad";
		return Response.status(Response.Status.OK).header("ETag", ETAG).entity(new Car("Ferrari", "red")).build();
	}

	@GET
	@Path("/{carId:\\d+}/modified")
	@Produces(MediaType.APPLICATION_JSON)
	public Response getCarByModified(@PathParam("carId") long carId, @HeaderParam("If-Modified-Since") String modified) {
		Date date = DateUtil.parseDate(modified);
		Random random = new Random();
		if (MODIFIED != null && MODIFIED.before(date) && random.nextBoolean()) {
			return Response.status(Response.Status.NOT_MODIFIED).header("Last-Modified", modified).build();
		}
		MODIFIED = new Date();
		return Response.status(Response.Status.OK).header("Last-Modified", MODIFIED).entity(new Car("Ferrari", "red")).build();
	}
}
